==> jc-1.4.0.tar.gz: polyglot/visit/DataFlow__24BoolItem.h <==
// public class polyglot.visit.DataFlow$BoolItem

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 39f6fe1993a1391b polyglot_visit_DataFlow__24BoolItem

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_polyglot_visit_DataFlow__24BoolItem_H_
#define _JC_polyglot_visit_DataFlow__24BoolItem_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_polyglot_visit_DataFlow__24Item$object;

// Typedefs
typedef struct _jc_polyglot_visit_DataFlow__24BoolItem$sub_refs	_jc_polyglot_visit_DataFlow__24BoolItem$sub_refs;
typedef struct _jc_polyglot_visit_DataFlow__24BoolItem$sub_nonrefs	_jc_polyglot_visit_DataFlow__24BoolItem$sub_nonrefs;
typedef struct _jc_polyglot_visit_DataFlow__24BoolItem$refs	_jc_polyglot_visit_DataFlow__24BoolItem$refs;
typedef struct _jc_polyglot_visit_DataFlow__24BoolItem$nonrefs	_jc_polyglot_visit_DataFlow__24BoolItem$nonrefs;
typedef struct _jc_polyglot_visit_DataFlow__24BoolItem$object	_jc_polyglot_visit_DataFlow__24BoolItem$object;

typedef const struct _jc_polyglot_visit_DataFlow__24BoolItem$vmethods	_jc_polyglot_visit_DataFlow__24BoolItem$vmethods;
typedef const struct _jc_polyglot_visit_DataFlow__24BoolItem$vtable	_jc_polyglot_visit_DataFlow__24BoolItem$vtable;
typedef const struct _jc_polyglot_visit_DataFlow__24BoolItem$vtype	_jc_polyglot_visit_DataFlow__24BoolItem$vtype;

// Constructors
extern void _jc_polyglot_visit_DataFlow__24BoolItem$method$_init$a144d301d5744384(_jc_env *, struct _jc_polyglot_visit_DataFlow__24BoolItem$object *, struct _jc_polyglot_visit_DataFlow__24Item$object *, struct _jc_polyglot_visit_DataFlow__24Item$object *);

// Virtual methods
extern struct _jc_java_lang_String$object *_jc_polyglot_visit_DataFlow__24BoolItem$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_polyglot_visit_DataFlow__24BoolItem$object *);

// Virtual method descriptors
extern _jc_method _jc_polyglot_visit_DataFlow__24BoolItem$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_polyglot_visit_DataFlow__24BoolItem$vmethods {
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_polyglot_visit_DataFlow__24BoolItem$object *);
};

// Vtable
struct _jc_polyglot_visit_DataFlow__24BoolItem$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_visit_DataFlow__24BoolItem$vmethods	polyglot_visit_DataFlow__24BoolItem;
};

// Vtype
struct _jc_polyglot_visit_DataFlow__24BoolItem$vtype {
	_jc_type			type;
	_jc_polyglot_visit_DataFlow__24BoolItem$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_visit_DataFlow__24BoolItem$sub_refs {
	struct _jc_polyglot_visit_DataFlow__24Item$object	*trueItem;
	struct _jc_polyglot_visit_DataFlow__24Item$object	*falseItem;
};

// Reference instance fields (object)
struct _jc_polyglot_visit_DataFlow__24BoolItem$refs {
    _jc_polyglot_visit_DataFlow__24BoolItem$sub_refs	polyglot_visit_DataFlow__24BoolItem;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_visit_DataFlow__24BoolItem$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_polyglot_visit_DataFlow__24BoolItem$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_visit_DataFlow__24BoolItem$sub_nonrefs	polyglot_visit_DataFlow__24BoolItem;
};

// Object instance structure
struct _jc_polyglot_visit_DataFlow__24BoolItem$object {
	_jc_polyglot_visit_DataFlow__24BoolItem$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_visit_DataFlow__24BoolItem$vtype	*vtype;
	_jc_polyglot_visit_DataFlow__24BoolItem$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_visit_DataFlow__24BoolItem$vtype _jc_polyglot_visit_DataFlow__24BoolItem$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_visit_DataFlow__24BoolItem, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_visit_DataFlow__24BoolItem$class_object;

#endif	/* _JC_polyglot_visit_DataFlow__24BoolItem_H_ */

==> jc-1.4.6.tar.gz: polyglot/visit/DataFlow__24BoolItem.h <==
// public class polyglot.visit.DataFlow$BoolItem

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 39f6fe1993a1391b polyglot_visit_DataFlow__24BoolItem

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_polyglot_visit_DataFlow__24BoolItem_H_
#define _JC_polyglot_visit_DataFlow__24BoolItem_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_polyglot_visit_DataFlow__24Item$object;

// Typedefs
typedef struct _jc_polyglot_visit_DataFlow__24BoolItem$sub_refs	_jc_polyglot_visit_DataFlow__24BoolItem$sub_refs;
typedef struct _jc_polyglot_visit_DataFlow__24BoolItem$sub_nonrefs	_jc_polyglot_visit_DataFlow__24BoolItem$sub_nonrefs;
typedef struct _jc_polyglot_visit_DataFlow__24BoolItem$refs	_jc_polyglot_visit_DataFlow__24BoolItem$refs;
typedef struct _jc_polyglot_visit_DataFlow__24BoolItem$nonrefs	_jc_polyglot_visit_DataFlow__24BoolItem$nonrefs;
typedef struct _jc_polyglot_visit_DataFlow__24BoolItem$object	_jc_polyglot_visit_DataFlow__24BoolItem$object;

typedef const struct _jc_polyglot_visit_DataFlow__24BoolItem$vmethods	_jc_polyglot_visit_DataFlow__24BoolItem$vmethods;
typedef const struct _jc_polyglot_visit_DataFlow__24BoolItem$vtable	_jc_polyglot_visit_DataFlow__24BoolItem$vtable;
typedef const struct _jc_polyglot_visit_DataFlow__24BoolItem$vtype	_jc_polyglot_visit_DataFlow__24BoolItem$vtype;

// Constructors
extern void _jc_polyglot_visit_DataFlow__24BoolItem$method$_init$a144d301d5744384(_jc_env *, struct _jc_polyglot_visit_DataFlow__24BoolItem$object *, struct _jc_polyglot_visit_DataFlow__24Item$object *, struct _jc_polyglot_visit_DataFlow__24Item$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_String$object *_jc_polyglot_visit_DataFlow__24BoolItem$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_polyglot_visit_DataFlow__24BoolItem$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_polyglot_visit_DataFlow__24BoolItem$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_polyglot_visit_DataFlow__24BoolItem$vmethods {
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_polyglot_visit_DataFlow__24BoolItem$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_polyglot_visit_DataFlow__24BoolItem$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_visit_DataFlow__24BoolItem$vmethods	polyglot_visit_DataFlow__24BoolItem;
};

// Vtype
struct _jc_polyglot_visit_DataFlow__24BoolItem$vtype {
	_jc_type			type;
	_jc_polyglot_visit_DataFlow__24BoolItem$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_visit_DataFlow__24BoolItem$sub_refs {
	struct _jc_polyglot_visit_DataFlow__24Item$object	*trueItem;
	struct _jc_polyglot_visit_DataFlow__24Item$object	*falseItem;
};

// Reference instance fields (object)
struct _jc_polyglot_visit_DataFlow__24BoolItem$refs {
    _jc_polyglot_visit_DataFlow__24BoolItem$sub_refs	polyglot_visit_DataFlow__24BoolItem;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_visit_DataFlow__24BoolItem$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_polyglot_visit_DataFlow__24BoolItem$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_visit_DataFlow__24BoolItem$sub_nonrefs	polyglot_visit_DataFlow__24BoolItem;
};

// Object instance structure
struct _jc_polyglot_visit_DataFlow__24BoolItem$object {
	_jc_polyglot_visit_DataFlow__24BoolItem$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_visit_DataFlow__24BoolItem$vtype	*vtype;
	_jc_polyglot_visit_DataFlow__24BoolItem$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_visit_DataFlow__24BoolItem$vtype _jc_polyglot_visit_DataFlow__24BoolItem$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_visit_DataFlow__24BoolItem, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_visit_DataFlow__24BoolItem$class_object;

#endif	/* _JC_polyglot_visit_DataFlow__24BoolItem_H_ */
